@@ -6,7 +6,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 sub new {
     my $class = shift;
@@ -45,7 +45,7 @@ sub login {
     $self->get($1);
 	
 	# look for the base url for the mailbox
-	if ($self->{content} =~ m/_UM = "([^"]+)";/) {
+	if ($self->{content} =~ m/_UM\s*=\s*"([^"]+)"/) {
 		$self->{_WWWHotmail_base} = $1;
 	} else {
 	   	Carp::croak "Couldn't log in to Hotmail";
@@ -84,6 +84,21 @@ sub messages {
     return @{$self->{_WWWHotmail_msgs}};
 }
 
+sub compose {
+	my ($self,%args) = @_;
+	my @argkeys = ('to','cc','bcc','subject','body');
+	$self->get("/cgi-bin/compose?".$self->{_WWWHotmail_base});
+
+	$self->form_name('composeform');
+	for(@argkeys) {
+		$self->field($_ => $args{$_});
+	}
+	$self->field(_HMaction => 'Send');
+	$self->submit();
+	Carp::croak 'Send failed'
+		unless($self->content() =~ m/Your message has been sent to/ );
+}
+
 package WWW::Hotmail::Message;
 @WWW::Hotmail::Message::ISA = qw(WWW::Hotmail);
 
@@ -145,7 +160,7 @@ __END__
 
 =head1 NAME
 
-WWW::Hotmail - Connect to Hotmail and download messages
+WWW::Hotmail - Connect to Hotmail and download and send messages
 
 =head1 SYNOPSIS
 
@@ -153,6 +168,18 @@ WWW::Hotmail - Connect to Hotmail and download messages
   my $hotmail = new WWW::Hotmail;
   $hotmail->login('foo@hotmail.com', "bar");
   for ($hotmail->messages) { $_->retrieve->accept; $_->delete; }
+  $hotmail->compose(
+    to      => 'user@email.com,otheruser@otheremail.com',
+    subject => 'Hello Person!',
+    body    => q[Dear Person,
+  
+  I am writing today to tell you about something important.
+
+  Thanks for all your support.
+  
+  Sincerely,
+  Other Person
+  ]);
 
 =head1 DESCRIPTION
 
@@ -172,6 +199,13 @@ an email into a C<Mail::Audit> object - see L<Mail::Audit> for more
 details. C<from> gives you the from field. Finally C<delete> moves it
 to your trash.
 
+You can use the C<compose> message to send a message through the 
+account you are currently logged in to.  You should be able to use
+this method as many times and as often as you like during the life
+of the C<WWW::Hotmail> object.  As its argument, it takes a hash whose
+keys are C<to>, C<cc>, C<bcc>, C<subject>, C<body>.  Newlines should
+work fine in the C<body> argument.
+
 This module should work with email addresses at charter.com, compaq.net,
 hotmail.com, msn.com, passport.com, and webtv.net
 
@@ -183,7 +217,7 @@ L<WWW::Mechanize>, L<Mail::Audit>, C<gotmail>
 
 =head1 NOTE
 
-This module is reasonable fragile. It seems to work, but I haven't
+This module is reasonably fragile. It seems to work, but I haven't
 tested edge cases. If it breaks, you get to keep both pieces. I hope
 to improve it in the future, but this is enough for release.
 
